@@ -11,16 +11,14 @@ from typing import (
     Pattern,
     Sequence,
     TypedDict,
-    Union,
     cast,
     overload,
 )
 
-from ididi import Graph, INodeConfig
+from ididi import Graph
 from ididi.graph import Resolver
-from ididi.interfaces import IDependent
+from ididi.interfaces import NodeIgnoreConfig
 from msgspec import field
-from starlette.responses import StreamingResponse
 from typing_extensions import Self, Unpack
 
 from lihil.asgi import ASGIBase
@@ -39,7 +37,6 @@ from lihil.interface import (
     P,
     R,
     Record,
-    T,
 )
 from lihil.plugins import IPlugin
 from lihil.plugins.auth.oauth import AuthBase
@@ -53,9 +50,7 @@ from lihil.utils.string import (
     trim_path,
 )
 from lihil.utils.threading import async_wrapper
-from lihil.vendors import Request, Response
-
-DepNode = Union[IDependent[Any], tuple[IDependent[Any], INodeConfig]]
+from lihil.vendors import Request, Response, StreamingResponse
 
 
 class IEndpointProps(TypedDict, total=False):
@@ -75,7 +70,7 @@ class IEndpointProps(TypedDict, total=False):
     "Return Encoder"
     plugins: list[IPlugin]
     "Decorators to decorate the endpoint function"
-    deps: list[DepNode] | None
+    deps: list[Any] | None
     "Dependencies that might be used in "
 
 
@@ -90,7 +85,7 @@ class EndpointProps(Record, kw_only=True):
     tags: list[str] | None = None
     encoder: IEncoder | None = None
     plugins: list[IPlugin] = field(default_factory=list[IPlugin])
-    deps: list[DepNode] | None = None
+    deps: list[Any] | None = None
 
     @classmethod
     def from_unpack(cls, **iconfig: Unpack[IEndpointProps]):
@@ -336,13 +331,11 @@ class RouteBase(ASGIBase):
         scope["path_params"] = m.groupdict()
         return True
 
-    def add_nodes(
-        self, *nodes: Union[IDependent[T], tuple[IDependent[T], INodeConfig]]
-    ) -> None:
+    def add_nodes(self, *nodes: Any) -> None:
         self._graph.add_nodes(*nodes)
 
-    def factory(self, node: Callable[..., R], **node_config: Unpack[INodeConfig]):
-        return self._graph.node(node, **node_config)
+    def factory(self, node: Callable[..., R], *, ignore: NodeIgnoreConfig = ()):
+        return self._graph.node(node, ignore=ignore)
 
     def _setup(
         self, graph: Graph | None = None, workers: ThreadPoolExecutor | None = None
@@ -373,7 +366,8 @@ class Route(RouteBase):
             self._props = EndpointProps()
 
         if self._props.deps:
-            self._graph.add_nodes(*self._props.deps)
+            for dep in self._props.deps:
+                self._graph.node(dep)
 
         self._is_setup: bool = False
 
