@@ -10,6 +10,7 @@ from typing import (
     Callable,
     Literal,
     Mapping,
+    Sequence,
     TypeGuard,
     Union,
     cast,
@@ -19,16 +20,15 @@ from typing import (
 )
 from warnings import warn
 
-from ididi import DependentNode, Graph, INode, NodeConfig, Resolver
+from ididi import DependentNode, Graph, INode, Resolver
 from ididi.config import USE_FACTORY_MARK
 from ididi.utils.param_utils import MISSING as IDIDI_MISSING
 from msgspec import Struct, convert
 from msgspec.structs import NODEFAULT, FieldInfo
 from msgspec.structs import fields as get_fields
-from starlette.datastructures import FormData
 from typing_extensions import NotRequired, TypeAliasType, is_typeddict
 
-from lihil.errors import InvalidParamError, InvalidParamPackError
+from lihil.errors import InvalidParamError, InvalidParamPackError, NotSupportedError
 from lihil.interface import MISSING as LIHIL_MISSING
 from lihil.interface import IRequest, Maybe, R, T, is_present
 from lihil.interface.marks import Struct
@@ -42,7 +42,7 @@ from lihil.utils.typing import (
     is_union_type,
     lenient_issubclass,
 )
-from lihil.vendors import Request, UploadFile, WebSocket
+from lihil.vendors import FormData, Request, UploadFile, WebSocket
 
 from .params import (
     BodyMeta,
@@ -125,7 +125,7 @@ def filedeocder_factory(filename: str):
 
 def file_body_param(
     name: str,
-    type_: type[UploadFile],
+    type_: type[UploadFile] | list[UploadFile],
     annotation: Any,
     default: Any,
     meta: FormMeta | None = None,
@@ -198,10 +198,16 @@ def lexient_get_fields(ptype: type[Any]):
 def formdecoder_factory(
     ptype: type[T] | UnionType,
 ) -> IDecoder[FormData, T] | IDecoder[bytes, T]:
-    if not is_structured_type(ptype, homogeneous_union=True):
+    porigin = get_origin(ptype)
+    if lenient_issubclass(porigin, Sequence):
+        for t in get_args(ptype):
+            if is_structured_type(t, homogeneous_union=True):
+                continue
+            raise InvalidParamError(f"Form type {t} must be a structured type")
+    elif not is_structured_type(ptype, homogeneous_union=True):
         raise InvalidParamError(f"Form type must be a structured type")
 
-    if get_origin(ptype) is UnionType:
+    if porigin is UnionType:
         raise InvalidParamError(f"Union of multiple form type is not supported yet")
 
     ptype = cast(type[T], ptype)
@@ -324,22 +330,18 @@ class EndpointParser:
         self.node_derived = set[str]()
 
     def _parse_node(
-        self, node_type: INode[..., Any], node_config: NodeConfig | None = None
+        self, node_type: INode[..., Any], reuse: Maybe[bool] = LIHIL_MISSING
     ) -> list["ParsedParam[Any]"]:
-        if node_config:
-            node = self.graph.analyze(node_type, config=node_config)
+        if is_present(reuse):
+            node = self.graph.analyze(node_type, reuse=reuse)
         else:
             node = self.graph.analyze(node_type)
 
-        ignores = node_config.ignore if node_config else ()
-
         params: list[Any | DependentNode] = [node]
-        for dep_name, dep in node.dependencies.items():
+        for dep in node.dependencies:
             ptype, default = dep.param_type, dep.default_
-            if dep_name in ignores or ptype in ignores:
-                continue
             default = LIHIL_MISSING if default is IDIDI_MISSING else default
-            sub_params = self.parse_param(dep_name, cast(type, ptype), default)
+            sub_params = self.parse_param(dep.name, cast(type, ptype), default)
             for sp in sub_params:
                 if not isinstance(sp, DependentNode):
                     self.node_derived.add(sp.name)
@@ -502,6 +504,8 @@ class EndpointParser:
                     meta=param_meta,
                 )
                 return cast(FormParam[T], body_param)
+            elif type_ == list[UploadFile]:
+                raise NotSupportedError(f"{type_} is currently not supported")
 
             content_type = param_meta.content_type or "multipart/form-data"
             decoder = param_meta.decoder or formdecoder_factory(type_)
@@ -675,8 +679,8 @@ class EndpointParser:
                     else:
                         param_meta = meta
                 elif meta == USE_FACTORY_MARK:
-                    factory, config = parsed_metas[idx + 1], parsed_metas[idx + 2]
-                    return self._parse_node(factory, config)
+                    factory, reuse = parsed_metas[idx + 1], parsed_metas[idx + 2]
+                    return self._parse_node(factory, reuse)
 
         if source is not None:
             if param_meta is None:
