@@ -23,7 +23,7 @@ from lihil.config import DEFAULT_CONFIG, lhl_set_config
 from lihil.errors import InvalidParamError, StatusConflictError
 from lihil.interface import Base
 from lihil.local_client import LocalClient
-from lihil.plugins.auth.jwt import JWTAuthParam, JWTAuthPlugin, JWTConfig
+from lihil.plugins.auth.jwt import JWTAuthParam, JWTConfig
 from lihil.plugins.auth.oauth import OAuth2PasswordFlow, OAuthLoginForm
 from lihil.signature.parser import EndpointParser
 from lihil.utils.threading import async_wrapper
@@ -198,6 +198,40 @@ async def test_scoped_endpoint(rusers: Route, lc: LocalClient):
     await lc.call_endpoint(ep)
 
 
+async def test_regular_exception_solver():
+    """Register a solver for a regular Python exception and ensure it's used.
+
+    This verifies that `problem_solver` supports non-HTTP exceptions and that
+    `Endpoint.make_call` routes such exceptions to the registered handler.
+    """
+
+    from lihil.problems import problem_solver, get_solver
+    from lihil.vendors import Response
+
+    class RegularError(Exception):
+        pass
+
+    @problem_solver
+    def handle_regular_error(req: Request, exc: RegularError) -> Response:
+        return Response("regular exception handled", status_code=501, media_type="text/plain")
+
+    # Verify solver lookup works for regular exceptions
+    assert get_solver(RegularError("boom")) is handle_regular_error
+
+    # Build a route that raises the regular exception
+    route = Route("/regular-exc")
+
+    async def raises_regular():
+        raise RegularError("boom")
+
+    route.get(raises_regular)
+
+    client = LocalClient()
+    resp = await client.call_route(route, method="GET")
+    assert resp.status_code == 501
+    assert await resp.text() == "regular exception handled"
+
+
 async def test_ep_drop_body(rusers: Route, lc: LocalClient):
 
     async def get() -> Annotated[Empty, status.BAD_REQUEST]:
@@ -488,7 +522,6 @@ async def test_ep_require_resolver(rusers: Route, lc: LocalClient):
     assert side_effect == [1]
 
 
-@pytest.mark.debug
 async def test_config_nonscoped_ep_to_be_scoped(rusers: Route, lc: LocalClient):
     class Engine: ...
 
@@ -589,11 +622,15 @@ async def test_oauth2_not_plugin():
 
 @pytest.fixture
 def jwt_auth_plugin():
+    # Import lazily to avoid errors when auth extras are not installed
+    from lihil.plugins.auth.jwt import JWTAuthPlugin
+
     return JWTAuthPlugin(jwt_secret="mysecret", jwt_algorithms="HS256")
 
 
+@pytest.mark.requires_auth
 async def test_endpoint_with_jwt_decode_fail(
-    testroute: Route, lc: LocalClient, jwt_auth_plugin: JWTAuthPlugin
+    testroute: Route, lc: LocalClient, jwt_auth_plugin
 ):
     async def get_me(
         token: Annotated[
@@ -614,8 +651,9 @@ async def test_endpoint_with_jwt_decode_fail(
     assert res.status_code == 401
 
 
+@pytest.mark.requires_auth
 async def test_endpoint_login_and_validate(
-    testroute: Route, lc: LocalClient, jwt_auth_plugin: JWTAuthPlugin
+    testroute: Route, lc: LocalClient, jwt_auth_plugin
 ):
     @testroute.get(
         auth_scheme=OAuth2PasswordFlow(token_url="token"),
