@@ -16,7 +16,7 @@ from lihil.oas.schema import (
     get_ep_security,
     get_path_item_from_route,
     get_resp_schemas,
-    json_schema,
+    oas_schema,
 )
 from lihil.plugins.auth.oauth import OAuth2PasswordFlow
 from lihil.problems import collect_problems
@@ -262,35 +262,33 @@ async def test_ep_with_auth_scheme():
     get_resp_schemas(ep, {}, "")
 
 
-from pydantic import BaseModel
-
-
-class PydanticBody(BaseModel):
-    name: str
-    age: str
-
-
-class PydanticResp(BaseModel):
-    email: str
-
-
+@pytest.mark.requires_pydantic
 async def test_route_with_pydantic_schema():
+    from pydantic import BaseModel
+
+    class PydanticBody(BaseModel):
+        name: str
+        age: str
+
+    class PydanticResp(BaseModel):
+        email: str
+
+    lc = LocalClient()
 
     async def create_user(user: PydanticBody) -> PydanticResp: ...
 
-    lc = LocalClient()
     ep = await lc.make_endpoint(create_user)
 
     result = generate_op_from_ep(ep, {}, {}, "problems")
     assert result
 
 
-def test_json_schema_of_msgspec_and_pydantic():
+def test_oas_schema_of_msgspec_and_pydantic():
     class MSUser(Struct):
         id: str
         email: str
 
-    result = json_schema(MSUser)
+    result = oas_schema(MSUser)
     assert result
 
 
@@ -312,7 +310,6 @@ async def test_single_value_param_not_required():
     assert not ep.sig.header_params["address"].required
 
 
-@pytest.mark.debug
 def test_generate_tasg():
     class UserProfileDTO(Payload): ...
 
@@ -334,5 +331,5 @@ def test_generate_tasg():
     oas = lhl.genereate_oas()
 
     for path, itm in oas.paths.items():
-        assert itm.get.tags == ["profiles"]
-        break
+        if path.endswith("profiles"):
+            assert itm.get.tags == ["profiles"]
