@@ -1,17 +1,18 @@
 from typing import Annotated, Generic, TypeAlias, TypeVar, Union
 
 import pytest
+from ididi.errors import NotSupportedError
 
-from lihil import Param
+from lihil import Param, use
 from lihil.interface import CustomEncoder
 from lihil.utils.typing import (
     deannotate,
     get_origin_pro,
     is_nontextual_sequence,
+    is_pydantic_model,
     is_text_type,
     is_union_type,
     lenient_issubclass,
-    should_use_pydantic,
 )
 
 T = TypeVar("T")
@@ -185,11 +186,11 @@ def test_lenient_issubclass():
     assert not lenient_issubclass(5, str)
 
 
-@pytest.mark.debug
-def test_should_use_pydantic():
-    assert not should_use_pydantic(str)
-    assert not should_use_pydantic(int)
-    assert not should_use_pydantic(list[int])
+@pytest.mark.requires_pydantic
+def test_is_pydantic_model():
+    assert not is_pydantic_model(str)
+    assert not is_pydantic_model(int)
+    assert not is_pydantic_model(list[int])
 
     from msgspec import Struct
     from pydantic import BaseModel
@@ -200,8 +201,22 @@ def test_should_use_pydantic():
     class MsgspecType(Struct):
         name: str
 
-    assert should_use_pydantic(PydanticType)
-    assert should_use_pydantic(list[PydanticType])
-    assert should_use_pydantic(dict[str, PydanticType])
+    assert is_pydantic_model(PydanticType)
+    assert is_pydantic_model(list[PydanticType])
+    assert is_pydantic_model(dict[str, PydanticType])
 
-    assert not should_use_pydantic(MsgspecType)
+    assert not is_pydantic_model(MsgspecType)
+
+
+from lihil import Route
+
+
+def test_route_typing():
+    route = Route()
+
+    route.add_nodes(use(int))
+
+
+def test_algo():
+    with pytest.raises(NotSupportedError):
+        _ = Route(deps=[dict(a=1, b=2)])
